diff --git a/bin/json/game_puggsypasscheck.json b/bin/json/game_puggsypasscheck.json
new file mode 100644
index 000000000..fcd36683c
--- /dev/null
+++ b/bin/json/game_puggsypasscheck.json
@@ -0,0 +1,212 @@
+[
+ {
+ "id": 10001,
+ "pay_id": "passcheck_1",
+ "parameter": 5,
+ "unlock_text": {
+ "key": "passcheck_passcheck_unlock_text_10001",
+ "text": "{0}个地格"
+ },
+ "free_reward": {
+ "a": "attr",
+ "t": "diamond",
+ "n": 30
+ },
+ "pay_reward": [
+ {
+ "a": "attr",
+ "t": "diamond",
+ "n": 300
+ }
+ ]
+ },
+ {
+ "id": 10002,
+ "pay_id": "passcheck_1",
+ "parameter": 10,
+ "unlock_text": {
+ "key": "passcheck_passcheck_unlock_text_10002",
+ "text": "{0}个地格"
+ },
+ "free_reward": {
+ "a": "attr",
+ "t": "diamond",
+ "n": 30
+ },
+ "pay_reward": [
+ {
+ "a": "attr",
+ "t": "diamond",
+ "n": 300
+ }
+ ]
+ },
+ {
+ "id": 10003,
+ "pay_id": "passcheck_1",
+ "parameter": 15,
+ "unlock_text": {
+ "key": "passcheck_passcheck_unlock_text_10003",
+ "text": "{0}个地格"
+ },
+ "free_reward": {
+ "a": "attr",
+ "t": "diamond",
+ "n": 30
+ },
+ "pay_reward": [
+ {
+ "a": "attr",
+ "t": "diamond",
+ "n": 300
+ }
+ ]
+ },
+ {
+ "id": 10004,
+ "pay_id": "passcheck_1",
+ "parameter": 20,
+ "unlock_text": {
+ "key": "passcheck_passcheck_unlock_text_10004",
+ "text": "{0}个地格"
+ },
+ "free_reward": {
+ "a": "attr",
+ "t": "diamond",
+ "n": 30
+ },
+ "pay_reward": [
+ {
+ "a": "attr",
+ "t": "diamond",
+ "n": 300
+ }
+ ]
+ },
+ {
+ "id": 10005,
+ "pay_id": "passcheck_1",
+ "parameter": 25,
+ "unlock_text": {
+ "key": "passcheck_passcheck_unlock_text_10005",
+ "text": "{0}个地格"
+ },
+ "free_reward": {
+ "a": "attr",
+ "t": "diamond",
+ "n": 30
+ },
+ "pay_reward": [
+ {
+ "a": "attr",
+ "t": "diamond",
+ "n": 300
+ }
+ ]
+ },
+ {
+ "id": 10006,
+ "pay_id": "passcheck_1",
+ "parameter": 30,
+ "unlock_text": {
+ "key": "passcheck_passcheck_unlock_text_10006",
+ "text": "{0}个地格"
+ },
+ "free_reward": {
+ "a": "attr",
+ "t": "diamond",
+ "n": 30
+ },
+ "pay_reward": [
+ {
+ "a": "attr",
+ "t": "diamond",
+ "n": 300
+ }
+ ]
+ },
+ {
+ "id": 10007,
+ "pay_id": "passcheck_1",
+ "parameter": 35,
+ "unlock_text": {
+ "key": "passcheck_passcheck_unlock_text_10007",
+ "text": "{0}个地格"
+ },
+ "free_reward": {
+ "a": "attr",
+ "t": "diamond",
+ "n": 30
+ },
+ "pay_reward": [
+ {
+ "a": "attr",
+ "t": "diamond",
+ "n": 300
+ }
+ ]
+ },
+ {
+ "id": 10008,
+ "pay_id": "passcheck_1",
+ "parameter": 40,
+ "unlock_text": {
+ "key": "passcheck_passcheck_unlock_text_10008",
+ "text": "{0}个地格"
+ },
+ "free_reward": {
+ "a": "attr",
+ "t": "diamond",
+ "n": 30
+ },
+ "pay_reward": [
+ {
+ "a": "attr",
+ "t": "diamond",
+ "n": 300
+ }
+ ]
+ },
+ {
+ "id": 10009,
+ "pay_id": "passcheck_1",
+ "parameter": 45,
+ "unlock_text": {
+ "key": "passcheck_passcheck_unlock_text_10009",
+ "text": "{0}个地格"
+ },
+ "free_reward": {
+ "a": "attr",
+ "t": "diamond",
+ "n": 30
+ },
+ "pay_reward": [
+ {
+ "a": "attr",
+ "t": "diamond",
+ "n": 300
+ }
+ ]
+ },
+ {
+ "id": 10010,
+ "pay_id": "passcheck_1",
+ "parameter": 50,
+ "unlock_text": {
+ "key": "passcheck_passcheck_unlock_text_10010",
+ "text": "{0}个地格"
+ },
+ "free_reward": {
+ "a": "attr",
+ "t": "diamond",
+ "n": 30
+ },
+ "pay_reward": [
+ {
+ "a": "attr",
+ "t": "diamond",
+ "n": 300
+ }
+ ]
+ }
+]
\ No newline at end of file
diff --git a/modules/island/api_receive.go b/modules/island/api_receive.go
new file mode 100644
index 000000000..92e857443
--- /dev/null
+++ b/modules/island/api_receive.go
@@ -0,0 +1,72 @@
+package island
+
+import (
+ "go_dreamfactory/comm"
+ "go_dreamfactory/pb"
+ cfg "go_dreamfactory/sys/configure/structs"
+)
+
+// 参数校验
+func (this *apiComp) ReceiveCheck(session comm.IUserSession, req *pb.IsLandReceiveReq) (errdata *pb.ErrorData) {
+
+ return
+}
+
+// /获取系统公告
+func (this *apiComp) Receive(session comm.IUserSession, req *pb.IsLandReceiveReq) (errdata *pb.ErrorData) {
+ var (
+ info *pb.DBIsland
+ warorder *pb.Warorder
+ confs []*cfg.GamePuggsyPasscheckData
+ awards []*cfg.Gameatn
+ award []*pb.UserAtno
+ err error
+ )
+ if errdata = this.ReceiveCheck(session, req); errdata != nil {
+ return
+ }
+ if info, err = this.module.model.getmodel(session.GetUserId()); err != nil {
+ errdata = &pb.ErrorData{
+ Code: pb.ErrorCode_DBError,
+ Title: pb.ErrorCode_DBError.ToString(),
+ Message: err.Error(),
+ }
+ return
+ }
+ if confs, err = this.module.configure.getGamePuggsyPasscheckData(); err != nil {
+ errdata = &pb.ErrorData{
+ Code: pb.ErrorCode_ConfigNoFound,
+ Title: pb.ErrorCode_ConfigNoFound.ToString(),
+ Message: err.Error(),
+ }
+ return
+ }
+
+ awards = make([]*cfg.Gameatn, 0)
+ for _, v := range confs {
+ if v.Parameter <= int32(len(info.Nodes)) {
+ if warorder.Freeprogress < v.Parameter {
+ awards = append(awards, v.FreeReward)
+ }
+ if warorder.Vip {
+ if warorder.Payprogress < v.Parameter {
+ awards = append(awards, v.PayReward...)
+ }
+ }
+ }
+ }
+ warorder.Freeprogress = int32(len(info.Nodes))
+ if warorder.Vip {
+ warorder.Payprogress = int32(len(info.Nodes))
+ }
+
+ if errdata, award = this.module.DispenseAtno(session, awards, true); errdata != nil {
+ return
+ }
+ this.module.model.Change(session.GetUserId(), map[string]interface{}{
+ "freeprogress": info.Freeprogress,
+ "payprogress": info.Payprogress,
+ })
+ session.SendMsg(string(this.module.GetType()), "receive", &pb.IsLandReceiveResp{Info: info, Award: award})
+ return
+}
diff --git a/modules/island/api_upgrade.go b/modules/island/api_upgrade.go
new file mode 100644
index 000000000..e2a9a73bc
--- /dev/null
+++ b/modules/island/api_upgrade.go
@@ -0,0 +1,60 @@
+package island
+
+import (
+ "fmt"
+ "go_dreamfactory/comm"
+ "go_dreamfactory/pb"
+ cfg "go_dreamfactory/sys/configure/structs"
+)
+
+// 参数校验
+func (this *apiComp) UpgradeCheck(session comm.IUserSession, req *pb.IsLandUpgradeReq) (errdata *pb.ErrorData) {
+
+ return
+}
+
+// /获取自己的排行榜信息
+func (this *apiComp) Upgrade(session comm.IUserSession, req *pb.IsLandUpgradeReq) (errdata *pb.ErrorData) {
+ var (
+ info *pb.DBIsland
+ conf *cfg.GamePuggsySkillData
+ ok bool
+ err error
+ )
+ if errdata = this.UpgradeCheck(session, req); errdata != nil {
+ return
+ }
+ if info, err = this.module.model.getmodel(session.GetUserId()); err != nil {
+ errdata = &pb.ErrorData{
+ Code: pb.ErrorCode_DBError,
+ Title: pb.ErrorCode_DBError.ToString(),
+ Message: err.Error(),
+ }
+ return
+ }
+ if conf, err = this.module.configure.getGamePuggsySkillData(req.Nid); err != nil {
+ errdata = &pb.ErrorData{
+ Code: pb.ErrorCode_ConfigNoFound,
+ Title: pb.ErrorCode_ConfigNoFound.ToString(),
+ Message: err.Error(),
+ }
+ return
+ }
+ if _, ok = info.Nodes[conf.Id]; ok {
+ errdata = &pb.ErrorData{
+ Code: pb.ErrorCode_ReqParameterError,
+ Title: pb.ErrorCode_ReqParameterError.ToString(),
+ Message: fmt.Sprintf("%d Unlocked!", conf.Id),
+ }
+ return
+ }
+ if errdata = this.module.ConsumeRes(session, conf.CostItem, true); errdata != nil {
+ return
+ }
+ info.Nodes[conf.Id] = 1
+ this.module.model.Change(session.GetUserId(), map[string]interface{}{
+ "nodes": info.Nodes,
+ })
+ session.SendMsg(string(this.module.GetType()), "upgrade", &pb.IsLandUpgradeReq{Nid: conf.NodeId})
+ return
+}
diff --git a/modules/island/configure.go b/modules/island/configure.go
index d5914c632..3696f2d08 100644
--- a/modules/island/configure.go
+++ b/modules/island/configure.go
@@ -10,10 +10,11 @@ import (
)
const (
- game_puggsyevent = "game_puggsyevent.json"
- game_puggsyskill = "game_puggsyskill.json"
- game_puggsyfight = "game_puggsyfight.json"
- game_puggsyscore = "game_puggsyscore.json"
+ game_puggsyevent = "game_puggsyevent.json"
+ game_puggsyskill = "game_puggsyskill.json"
+ game_puggsyfight = "game_puggsyfight.json"
+ game_puggsyscore = "game_puggsyscore.json"
+ game_puggsypasscheck = "game_puggsypasscheck.json"
)
// /背包配置管理组件
@@ -30,6 +31,7 @@ func (this *ConfigureComp) Init(service core.IService, module core.IModule, comp
err = this.LoadConfigure(game_puggsyskill, cfg.NewGamePuggsySkill)
err = this.LoadConfigure(game_puggsyfight, cfg.NewGamePuggsyFight)
err = this.LoadConfigure(game_puggsyscore, cfg.NewGamePuggsyScore)
+ err = this.LoadConfigure(game_puggsypasscheck, cfg.NewGamePuggsyPasscheck)
return
}
@@ -110,3 +112,16 @@ func (this *ConfigureComp) getGamePuggsyScoreData(harm int32) (results *cfg.Game
}
return
}
+
+// 获取伤害对应的评分组
+func (this *ConfigureComp) getGamePuggsyPasscheckData() (results []*cfg.GamePuggsyPasscheckData, err error) {
+ var (
+ v interface{}
+ )
+ if v, err = this.GetConfigure(game_puggsyscore); err != nil {
+ return
+ } else {
+ results = v.(*cfg.GamePuggsyPasscheck).GetDataList()
+ }
+ return
+}
diff --git a/modules/island/model.go b/modules/island/model.go
index 1a1897db6..70d23988e 100644
--- a/modules/island/model.go
+++ b/modules/island/model.go
@@ -38,6 +38,7 @@ func (this *modelComp) getmodel(uid string) (result *pb.DBIsland, err error) {
Id: primitive.NewObjectID().Hex(),
Uid: uid,
Islands: make(map[int32]*pb.DBIslandItem),
+ Nodes: make(map[int32]int32),
}
if err = this.Add(uid, result); err != nil {
this.module.Errorln(err)
diff --git a/pb/errorcode.pb.go b/pb/errorcode.pb.go
index 3cc651a4d..f619efa7d 100644
--- a/pb/errorcode.pb.go
+++ b/pb/errorcode.pb.go
@@ -451,12 +451,10 @@ const (
//捕羊大赛的
ErrorCode_CapturesheepRankCloseed ErrorCode = 5101 //排位比赛不在开启时间内
// xxl
- ErrorCode_EntertainCantSwap ErrorCode = 5201 //不能交换
- ErrorCode_EntertainNoPower ErrorCode = 5202 //对方操作
- ErrorCode_EntertainNoHeroSkill ErrorCode = 5203 //没找到该英雄对应的技能
- ErrorCode_EntertainNoEnergy ErrorCode = 5204 //技能能量不足
- ErrorCode_EntertainCreateFailed ErrorCode = 5205 // 创建房间失败
- ErrorCode_EntertainPlayerNoReady ErrorCode = 5206 // 玩家1还没准备不能开始游戏
+ ErrorCode_EntertainCantSwap ErrorCode = 5201 //不能交换
+ ErrorCode_EntertainNoPower ErrorCode = 5202 //对方操作
+ ErrorCode_EntertainNoHeroSkill ErrorCode = 5203 //没找到该英雄对应的技能
+ ErrorCode_EntertainNoEnergy ErrorCode = 5204 //技能能量不足
)
// Enum value maps for ErrorCode.
@@ -849,8 +847,6 @@ var (
5202: "EntertainNoPower",
5203: "EntertainNoHeroSkill",
5204: "EntertainNoEnergy",
- 5205: "EntertainCreateFailed",
- 5206: "EntertainPlayerNoReady",
}
ErrorCode_value = map[string]int32{
"Success": 0,
@@ -1240,8 +1236,6 @@ var (
"EntertainNoPower": 5202,
"EntertainNoHeroSkill": 5203,
"EntertainNoEnergy": 5204,
- "EntertainCreateFailed": 5205,
- "EntertainPlayerNoReady": 5206,
}
)
@@ -1276,7 +1270,7 @@ var File_errorcode_proto protoreflect.FileDescriptor
var file_errorcode_proto_rawDesc = []byte{
0x0a, 0x0f, 0x65, 0x72, 0x72, 0x6f, 0x72, 0x63, 0x6f, 0x64, 0x65, 0x2e, 0x70, 0x72, 0x6f, 0x74,
- 0x6f, 0x2a, 0x9d, 0x48, 0x0a, 0x09, 0x45, 0x72, 0x72, 0x6f, 0x72, 0x43, 0x6f, 0x64, 0x65, 0x12,
+ 0x6f, 0x2a, 0xe4, 0x47, 0x0a, 0x09, 0x45, 0x72, 0x72, 0x6f, 0x72, 0x43, 0x6f, 0x64, 0x65, 0x12,
0x0b, 0x0a, 0x07, 0x53, 0x75, 0x63, 0x63, 0x65, 0x73, 0x73, 0x10, 0x00, 0x12, 0x14, 0x0a, 0x10,
0x47, 0x61, 0x74, 0x65, 0x77, 0x61, 0x79, 0x45, 0x78, 0x63, 0x65, 0x70, 0x74, 0x69, 0x6f, 0x6e,
0x10, 0x01, 0x12, 0x11, 0x0a, 0x0d, 0x4e, 0x6f, 0x46, 0x69, 0x6e, 0x64, 0x53, 0x65, 0x72, 0x76,
@@ -1850,12 +1844,8 @@ var file_errorcode_proto_rawDesc = []byte{
0x65, 0x72, 0x10, 0xd2, 0x28, 0x12, 0x19, 0x0a, 0x14, 0x45, 0x6e, 0x74, 0x65, 0x72, 0x74, 0x61,
0x69, 0x6e, 0x4e, 0x6f, 0x48, 0x65, 0x72, 0x6f, 0x53, 0x6b, 0x69, 0x6c, 0x6c, 0x10, 0xd3, 0x28,
0x12, 0x16, 0x0a, 0x11, 0x45, 0x6e, 0x74, 0x65, 0x72, 0x74, 0x61, 0x69, 0x6e, 0x4e, 0x6f, 0x45,
- 0x6e, 0x65, 0x72, 0x67, 0x79, 0x10, 0xd4, 0x28, 0x12, 0x1a, 0x0a, 0x15, 0x45, 0x6e, 0x74, 0x65,
- 0x72, 0x74, 0x61, 0x69, 0x6e, 0x43, 0x72, 0x65, 0x61, 0x74, 0x65, 0x46, 0x61, 0x69, 0x6c, 0x65,
- 0x64, 0x10, 0xd5, 0x28, 0x12, 0x1b, 0x0a, 0x16, 0x45, 0x6e, 0x74, 0x65, 0x72, 0x74, 0x61, 0x69,
- 0x6e, 0x50, 0x6c, 0x61, 0x79, 0x65, 0x72, 0x4e, 0x6f, 0x52, 0x65, 0x61, 0x64, 0x79, 0x10, 0xd6,
- 0x28, 0x42, 0x06, 0x5a, 0x04, 0x2e, 0x3b, 0x70, 0x62, 0x62, 0x06, 0x70, 0x72, 0x6f, 0x74, 0x6f,
- 0x33,
+ 0x6e, 0x65, 0x72, 0x67, 0x79, 0x10, 0xd4, 0x28, 0x42, 0x06, 0x5a, 0x04, 0x2e, 0x3b, 0x70, 0x62,
+ 0x62, 0x06, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x33,
}
var (
diff --git a/pb/island_msg.pb.go b/pb/island_msg.pb.go
index e17d5c1e2..4466eee06 100644
--- a/pb/island_msg.pb.go
+++ b/pb/island_msg.pb.go
@@ -354,6 +354,204 @@ func (x *IsLandCompleteResp) GetAward() []*UserAtno {
return nil
}
+//升级节点
+type IsLandUpgradeReq struct {
+ state protoimpl.MessageState
+ sizeCache protoimpl.SizeCache
+ unknownFields protoimpl.UnknownFields
+
+ Nid int32 `protobuf:"varint,1,opt,name=nid,proto3" json:"nid"` //配置文件里的Id 升级的目标数据
+}
+
+func (x *IsLandUpgradeReq) Reset() {
+ *x = IsLandUpgradeReq{}
+ if protoimpl.UnsafeEnabled {
+ mi := &file_island_island_msg_proto_msgTypes[6]
+ ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
+ ms.StoreMessageInfo(mi)
+ }
+}
+
+func (x *IsLandUpgradeReq) String() string {
+ return protoimpl.X.MessageStringOf(x)
+}
+
+func (*IsLandUpgradeReq) ProtoMessage() {}
+
+func (x *IsLandUpgradeReq) ProtoReflect() protoreflect.Message {
+ mi := &file_island_island_msg_proto_msgTypes[6]
+ if protoimpl.UnsafeEnabled && x != nil {
+ ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
+ if ms.LoadMessageInfo() == nil {
+ ms.StoreMessageInfo(mi)
+ }
+ return ms
+ }
+ return mi.MessageOf(x)
+}
+
+// Deprecated: Use IsLandUpgradeReq.ProtoReflect.Descriptor instead.
+func (*IsLandUpgradeReq) Descriptor() ([]byte, []int) {
+ return file_island_island_msg_proto_rawDescGZIP(), []int{6}
+}
+
+func (x *IsLandUpgradeReq) GetNid() int32 {
+ if x != nil {
+ return x.Nid
+ }
+ return 0
+}
+
+//升级节点
+type IsLandUpgradeResp struct {
+ state protoimpl.MessageState
+ sizeCache protoimpl.SizeCache
+ unknownFields protoimpl.UnknownFields
+
+ Nid int32 `protobuf:"varint,1,opt,name=nid,proto3" json:"nid"` //成长线id 配置文件里面的 节点 字段
+ Lv int32 `protobuf:"varint,2,opt,name=lv,proto3" json:"lv"`
+}
+
+func (x *IsLandUpgradeResp) Reset() {
+ *x = IsLandUpgradeResp{}
+ if protoimpl.UnsafeEnabled {
+ mi := &file_island_island_msg_proto_msgTypes[7]
+ ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
+ ms.StoreMessageInfo(mi)
+ }
+}
+
+func (x *IsLandUpgradeResp) String() string {
+ return protoimpl.X.MessageStringOf(x)
+}
+
+func (*IsLandUpgradeResp) ProtoMessage() {}
+
+func (x *IsLandUpgradeResp) ProtoReflect() protoreflect.Message {
+ mi := &file_island_island_msg_proto_msgTypes[7]
+ if protoimpl.UnsafeEnabled && x != nil {
+ ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
+ if ms.LoadMessageInfo() == nil {
+ ms.StoreMessageInfo(mi)
+ }
+ return ms
+ }
+ return mi.MessageOf(x)
+}
+
+// Deprecated: Use IsLandUpgradeResp.ProtoReflect.Descriptor instead.
+func (*IsLandUpgradeResp) Descriptor() ([]byte, []int) {
+ return file_island_island_msg_proto_rawDescGZIP(), []int{7}
+}
+
+func (x *IsLandUpgradeResp) GetNid() int32 {
+ if x != nil {
+ return x.Nid
+ }
+ return 0
+}
+
+func (x *IsLandUpgradeResp) GetLv() int32 {
+ if x != nil {
+ return x.Lv
+ }
+ return 0
+}
+
+// 战令奖励领取
+type IsLandReceiveReq struct {
+ state protoimpl.MessageState
+ sizeCache protoimpl.SizeCache
+ unknownFields protoimpl.UnknownFields
+}
+
+func (x *IsLandReceiveReq) Reset() {
+ *x = IsLandReceiveReq{}
+ if protoimpl.UnsafeEnabled {
+ mi := &file_island_island_msg_proto_msgTypes[8]
+ ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
+ ms.StoreMessageInfo(mi)
+ }
+}
+
+func (x *IsLandReceiveReq) String() string {
+ return protoimpl.X.MessageStringOf(x)
+}
+
+func (*IsLandReceiveReq) ProtoMessage() {}
+
+func (x *IsLandReceiveReq) ProtoReflect() protoreflect.Message {
+ mi := &file_island_island_msg_proto_msgTypes[8]
+ if protoimpl.UnsafeEnabled && x != nil {
+ ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
+ if ms.LoadMessageInfo() == nil {
+ ms.StoreMessageInfo(mi)
+ }
+ return ms
+ }
+ return mi.MessageOf(x)
+}
+
+// Deprecated: Use IsLandReceiveReq.ProtoReflect.Descriptor instead.
+func (*IsLandReceiveReq) Descriptor() ([]byte, []int) {
+ return file_island_island_msg_proto_rawDescGZIP(), []int{8}
+}
+
+type IsLandReceiveResp struct {
+ state protoimpl.MessageState
+ sizeCache protoimpl.SizeCache
+ unknownFields protoimpl.UnknownFields
+
+ Info *DBIsland `protobuf:"bytes,1,opt,name=info,proto3" json:"info"`
+ Award []*UserAtno `protobuf:"bytes,4,rep,name=award,proto3" json:"award"` //奖励
+}
+
+func (x *IsLandReceiveResp) Reset() {
+ *x = IsLandReceiveResp{}
+ if protoimpl.UnsafeEnabled {
+ mi := &file_island_island_msg_proto_msgTypes[9]
+ ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
+ ms.StoreMessageInfo(mi)
+ }
+}
+
+func (x *IsLandReceiveResp) String() string {
+ return protoimpl.X.MessageStringOf(x)
+}
+
+func (*IsLandReceiveResp) ProtoMessage() {}
+
+func (x *IsLandReceiveResp) ProtoReflect() protoreflect.Message {
+ mi := &file_island_island_msg_proto_msgTypes[9]
+ if protoimpl.UnsafeEnabled && x != nil {
+ ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
+ if ms.LoadMessageInfo() == nil {
+ ms.StoreMessageInfo(mi)
+ }
+ return ms
+ }
+ return mi.MessageOf(x)
+}
+
+// Deprecated: Use IsLandReceiveResp.ProtoReflect.Descriptor instead.
+func (*IsLandReceiveResp) Descriptor() ([]byte, []int) {
+ return file_island_island_msg_proto_rawDescGZIP(), []int{9}
+}
+
+func (x *IsLandReceiveResp) GetInfo() *DBIsland {
+ if x != nil {
+ return x.Info
+ }
+ return nil
+}
+
+func (x *IsLandReceiveResp) GetAward() []*UserAtno {
+ if x != nil {
+ return x.Award
+ }
+ return nil
+}
+
var File_island_island_msg_proto protoreflect.FileDescriptor
var file_island_island_msg_proto_rawDesc = []byte{
@@ -392,8 +590,20 @@ var file_island_island_msg_proto_rawDesc = []byte{
0x05, 0x73, 0x74, 0x6f, 0x72, 0x79, 0x18, 0x02, 0x20, 0x01, 0x28, 0x05, 0x52, 0x05, 0x73, 0x74,
0x6f, 0x72, 0x79, 0x12, 0x1f, 0x0a, 0x05, 0x61, 0x77, 0x61, 0x72, 0x64, 0x18, 0x03, 0x20, 0x03,
0x28, 0x0b, 0x32, 0x09, 0x2e, 0x55, 0x73, 0x65, 0x72, 0x41, 0x74, 0x6e, 0x6f, 0x52, 0x05, 0x61,
- 0x77, 0x61, 0x72, 0x64, 0x42, 0x06, 0x5a, 0x04, 0x2e, 0x3b, 0x70, 0x62, 0x62, 0x06, 0x70, 0x72,
- 0x6f, 0x74, 0x6f, 0x33,
+ 0x77, 0x61, 0x72, 0x64, 0x22, 0x24, 0x0a, 0x10, 0x49, 0x73, 0x4c, 0x61, 0x6e, 0x64, 0x55, 0x70,
+ 0x67, 0x72, 0x61, 0x64, 0x65, 0x52, 0x65, 0x71, 0x12, 0x10, 0x0a, 0x03, 0x6e, 0x69, 0x64, 0x18,
+ 0x01, 0x20, 0x01, 0x28, 0x05, 0x52, 0x03, 0x6e, 0x69, 0x64, 0x22, 0x35, 0x0a, 0x11, 0x49, 0x73,
+ 0x4c, 0x61, 0x6e, 0x64, 0x55, 0x70, 0x67, 0x72, 0x61, 0x64, 0x65, 0x52, 0x65, 0x73, 0x70, 0x12,
+ 0x10, 0x0a, 0x03, 0x6e, 0x69, 0x64, 0x18, 0x01, 0x20, 0x01, 0x28, 0x05, 0x52, 0x03, 0x6e, 0x69,
+ 0x64, 0x12, 0x0e, 0x0a, 0x02, 0x6c, 0x76, 0x18, 0x02, 0x20, 0x01, 0x28, 0x05, 0x52, 0x02, 0x6c,
+ 0x76, 0x22, 0x12, 0x0a, 0x10, 0x49, 0x73, 0x4c, 0x61, 0x6e, 0x64, 0x52, 0x65, 0x63, 0x65, 0x69,
+ 0x76, 0x65, 0x52, 0x65, 0x71, 0x22, 0x53, 0x0a, 0x11, 0x49, 0x73, 0x4c, 0x61, 0x6e, 0x64, 0x52,
+ 0x65, 0x63, 0x65, 0x69, 0x76, 0x65, 0x52, 0x65, 0x73, 0x70, 0x12, 0x1d, 0x0a, 0x04, 0x69, 0x6e,
+ 0x66, 0x6f, 0x18, 0x01, 0x20, 0x01, 0x28, 0x0b, 0x32, 0x09, 0x2e, 0x44, 0x42, 0x49, 0x73, 0x6c,
+ 0x61, 0x6e, 0x64, 0x52, 0x04, 0x69, 0x6e, 0x66, 0x6f, 0x12, 0x1f, 0x0a, 0x05, 0x61, 0x77, 0x61,
+ 0x72, 0x64, 0x18, 0x04, 0x20, 0x03, 0x28, 0x0b, 0x32, 0x09, 0x2e, 0x55, 0x73, 0x65, 0x72, 0x41,
+ 0x74, 0x6e, 0x6f, 0x52, 0x05, 0x61, 0x77, 0x61, 0x72, 0x64, 0x42, 0x06, 0x5a, 0x04, 0x2e, 0x3b,
+ 0x70, 0x62, 0x62, 0x06, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x33,
}
var (
@@ -408,7 +618,7 @@ func file_island_island_msg_proto_rawDescGZIP() []byte {
return file_island_island_msg_proto_rawDescData
}
-var file_island_island_msg_proto_msgTypes = make([]protoimpl.MessageInfo, 6)
+var file_island_island_msg_proto_msgTypes = make([]protoimpl.MessageInfo, 10)
var file_island_island_msg_proto_goTypes = []interface{}{
(*IsLandInfoReq)(nil), // 0: IsLandInfoReq
(*IsLandInfoResp)(nil), // 1: IsLandInfoResp
@@ -416,25 +626,31 @@ var file_island_island_msg_proto_goTypes = []interface{}{
(*IsLandBattleResp)(nil), // 3: IsLandBattleResp
(*IsLandCompleteReq)(nil), // 4: IsLandCompleteReq
(*IsLandCompleteResp)(nil), // 5: IsLandCompleteResp
- (*DBIsland)(nil), // 6: DBIsland
- (*DBHero)(nil), // 7: DBHero
- (*BattleFormation)(nil), // 8: BattleFormation
- (*BattleInfo)(nil), // 9: BattleInfo
- (*BattleReport)(nil), // 10: BattleReport
- (*UserAtno)(nil), // 11: UserAtno
+ (*IsLandUpgradeReq)(nil), // 6: IsLandUpgradeReq
+ (*IsLandUpgradeResp)(nil), // 7: IsLandUpgradeResp
+ (*IsLandReceiveReq)(nil), // 8: IsLandReceiveReq
+ (*IsLandReceiveResp)(nil), // 9: IsLandReceiveResp
+ (*DBIsland)(nil), // 10: DBIsland
+ (*DBHero)(nil), // 11: DBHero
+ (*BattleFormation)(nil), // 12: BattleFormation
+ (*BattleInfo)(nil), // 13: BattleInfo
+ (*BattleReport)(nil), // 14: BattleReport
+ (*UserAtno)(nil), // 15: UserAtno
}
var file_island_island_msg_proto_depIdxs = []int32{
- 6, // 0: IsLandInfoResp.info:type_name -> DBIsland
- 7, // 1: IsLandInfoResp.heros:type_name -> DBHero
- 8, // 2: IsLandBattleReq.battle:type_name -> BattleFormation
- 9, // 3: IsLandBattleResp.info:type_name -> BattleInfo
- 10, // 4: IsLandCompleteReq.report:type_name -> BattleReport
- 11, // 5: IsLandCompleteResp.award:type_name -> UserAtno
- 6, // [6:6] is the sub-list for method output_type
- 6, // [6:6] is the sub-list for method input_type
- 6, // [6:6] is the sub-list for extension type_name
- 6, // [6:6] is the sub-list for extension extendee
- 0, // [0:6] is the sub-list for field type_name
+ 10, // 0: IsLandInfoResp.info:type_name -> DBIsland
+ 11, // 1: IsLandInfoResp.heros:type_name -> DBHero
+ 12, // 2: IsLandBattleReq.battle:type_name -> BattleFormation
+ 13, // 3: IsLandBattleResp.info:type_name -> BattleInfo
+ 14, // 4: IsLandCompleteReq.report:type_name -> BattleReport
+ 15, // 5: IsLandCompleteResp.award:type_name -> UserAtno
+ 10, // 6: IsLandReceiveResp.info:type_name -> DBIsland
+ 15, // 7: IsLandReceiveResp.award:type_name -> UserAtno
+ 8, // [8:8] is the sub-list for method output_type
+ 8, // [8:8] is the sub-list for method input_type
+ 8, // [8:8] is the sub-list for extension type_name
+ 8, // [8:8] is the sub-list for extension extendee
+ 0, // [0:8] is the sub-list for field type_name
}
func init() { file_island_island_msg_proto_init() }
@@ -519,6 +735,54 @@ func file_island_island_msg_proto_init() {
return nil
}
}
+ file_island_island_msg_proto_msgTypes[6].Exporter = func(v interface{}, i int) interface{} {
+ switch v := v.(*IsLandUpgradeReq); i {
+ case 0:
+ return &v.state
+ case 1:
+ return &v.sizeCache
+ case 2:
+ return &v.unknownFields
+ default:
+ return nil
+ }
+ }
+ file_island_island_msg_proto_msgTypes[7].Exporter = func(v interface{}, i int) interface{} {
+ switch v := v.(*IsLandUpgradeResp); i {
+ case 0:
+ return &v.state
+ case 1:
+ return &v.sizeCache
+ case 2:
+ return &v.unknownFields
+ default:
+ return nil
+ }
+ }
+ file_island_island_msg_proto_msgTypes[8].Exporter = func(v interface{}, i int) interface{} {
+ switch v := v.(*IsLandReceiveReq); i {
+ case 0:
+ return &v.state
+ case 1:
+ return &v.sizeCache
+ case 2:
+ return &v.unknownFields
+ default:
+ return nil
+ }
+ }
+ file_island_island_msg_proto_msgTypes[9].Exporter = func(v interface{}, i int) interface{} {
+ switch v := v.(*IsLandReceiveResp); i {
+ case 0:
+ return &v.state
+ case 1:
+ return &v.sizeCache
+ case 2:
+ return &v.unknownFields
+ default:
+ return nil
+ }
+ }
}
type x struct{}
out := protoimpl.TypeBuilder{
@@ -526,7 +790,7 @@ func file_island_island_msg_proto_init() {
GoPackagePath: reflect.TypeOf(x{}).PkgPath(),
RawDescriptor: file_island_island_msg_proto_rawDesc,
NumEnums: 0,
- NumMessages: 6,
+ NumMessages: 10,
NumExtensions: 0,
NumServices: 0,
},
diff --git a/sys/configure/structs/Game.PuggsyPasscheck.go b/sys/configure/structs/Game.PuggsyPasscheck.go
new file mode 100644
index 000000000..b657b1448
--- /dev/null
+++ b/sys/configure/structs/Game.PuggsyPasscheck.go
@@ -0,0 +1,42 @@
+//------------------------------------------------------------------------------
+//
+// This code was generated by a tool.
+// Changes to this file may cause incorrect behavior and will be lost if
+// the code is regenerated.
+//
+//------------------------------------------------------------------------------
+
+package cfg
+
+type GamePuggsyPasscheck struct {
+ _dataMap map[int32]*GamePuggsyPasscheckData
+ _dataList []*GamePuggsyPasscheckData
+}
+
+func NewGamePuggsyPasscheck(_buf []map[string]interface{}) (*GamePuggsyPasscheck, error) {
+ _dataList := make([]*GamePuggsyPasscheckData, 0, len(_buf))
+ dataMap := make(map[int32]*GamePuggsyPasscheckData)
+ for _, _ele_ := range _buf {
+ if _v, err2 := DeserializeGamePuggsyPasscheckData(_ele_); err2 != nil {
+ return nil, err2
+ } else {
+ _dataList = append(_dataList, _v)
+ dataMap[_v.Id] = _v
+ }
+ }
+ return &GamePuggsyPasscheck{_dataList:_dataList, _dataMap:dataMap}, nil
+}
+
+func (table *GamePuggsyPasscheck) GetDataMap() map[int32]*GamePuggsyPasscheckData {
+ return table._dataMap
+}
+
+func (table *GamePuggsyPasscheck) GetDataList() []*GamePuggsyPasscheckData {
+ return table._dataList
+}
+
+func (table *GamePuggsyPasscheck) Get(key int32) *GamePuggsyPasscheckData {
+ return table._dataMap[key]
+}
+
+
diff --git a/sys/configure/structs/Game.PuggsyPasscheckData.go b/sys/configure/structs/Game.PuggsyPasscheckData.go
new file mode 100644
index 000000000..9f98f1965
--- /dev/null
+++ b/sys/configure/structs/Game.PuggsyPasscheckData.go
@@ -0,0 +1,58 @@
+//------------------------------------------------------------------------------
+//
+// This code was generated by a tool.
+// Changes to this file may cause incorrect behavior and will be lost if
+// the code is regenerated.
+//
+//------------------------------------------------------------------------------
+
+package cfg
+
+import "errors"
+
+type GamePuggsyPasscheckData struct {
+ Id int32
+ PayId string
+ Parameter int32
+ UnlockText string
+ FreeReward *Gameatn
+ PayReward []*Gameatn
+}
+
+const TypeId_GamePuggsyPasscheckData = 2074500826
+
+func (*GamePuggsyPasscheckData) GetTypeId() int32 {
+ return 2074500826
+}
+
+func (_v *GamePuggsyPasscheckData)Deserialize(_buf map[string]interface{}) (err error) {
+ { var _ok_ bool; var _tempNum_ float64; if _tempNum_, _ok_ = _buf["id"].(float64); !_ok_ { err = errors.New("id error"); return }; _v.Id = int32(_tempNum_) }
+ { var _ok_ bool; if _v.PayId, _ok_ = _buf["pay_id"].(string); !_ok_ { err = errors.New("pay_id error"); return } }
+ { var _ok_ bool; var _tempNum_ float64; if _tempNum_, _ok_ = _buf["parameter"].(float64); !_ok_ { err = errors.New("parameter error"); return }; _v.Parameter = int32(_tempNum_) }
+ {var _ok_ bool; var __json_text__ map[string]interface{}; if __json_text__, _ok_ = _buf["unlock_text"].(map[string]interface{}) ; !_ok_ { err = errors.New("_v.UnlockText error"); return }; { var _ok_ bool; if _, _ok_ = __json_text__["key"].(string); !_ok_ { err = errors.New("key error"); return } }; { var _ok_ bool; if _v.UnlockText, _ok_ = __json_text__["text"].(string); !_ok_ { err = errors.New("text error"); return } } }
+ { var _ok_ bool; var _x_ map[string]interface{}; if _x_, _ok_ = _buf["free_reward"].(map[string]interface{}); !_ok_ { err = errors.New("free_reward error"); return }; if _v.FreeReward, err = DeserializeGameatn(_x_); err != nil { return } }
+ {
+ var _arr_ []interface{}
+ var _ok_ bool
+ if _arr_, _ok_ = _buf["pay_reward"].([]interface{}); !_ok_ { err = errors.New("pay_reward error"); return }
+
+ _v.PayReward = make([]*Gameatn, 0, len(_arr_))
+
+ for _, _e_ := range _arr_ {
+ var _list_v_ *Gameatn
+ { var _ok_ bool; var _x_ map[string]interface{}; if _x_, _ok_ = _e_.(map[string]interface{}); !_ok_ { err = errors.New("_list_v_ error"); return }; if _list_v_, err = DeserializeGameatn(_x_); err != nil { return } }
+ _v.PayReward = append(_v.PayReward, _list_v_)
+ }
+ }
+
+ return
+}
+
+func DeserializeGamePuggsyPasscheckData(_buf map[string]interface{}) (*GamePuggsyPasscheckData, error) {
+ v := &GamePuggsyPasscheckData{}
+ if err := v.Deserialize(_buf); err == nil {
+ return v, nil
+ } else {
+ return nil, err
+ }
+}
diff --git a/sys/configure/structs/Tables.go b/sys/configure/structs/Tables.go
index b2d206427..9c33551de 100644
--- a/sys/configure/structs/Tables.go
+++ b/sys/configure/structs/Tables.go
@@ -288,6 +288,7 @@ type Tables struct {
PuggsyFight *GamePuggsyFight
PuggsyScore *GamePuggsyScore
PuggsySkill *GamePuggsySkill
+ PuggsyPasscheck *GamePuggsyPasscheck
}
func NewTables(loader JsonLoader) (*Tables, error) {
@@ -1957,5 +1958,11 @@ func NewTables(loader JsonLoader) (*Tables, error) {
if tables.PuggsySkill, err = NewGamePuggsySkill(buf) ; err != nil {
return nil, err
}
+ if buf, err = loader("game_puggsypasscheck") ; err != nil {
+ return nil, err
+ }
+ if tables.PuggsyPasscheck, err = NewGamePuggsyPasscheck(buf) ; err != nil {
+ return nil, err
+ }
return tables, nil
}
diff --git a/pb/island_db.pb.go b/pb/island_db.pb.go
index d7e733240..140825a2a 100644
--- a/pb/island_db.pb.go
+++ b/pb/island_db.pb.go
@@ -25,9 +25,13 @@ type DBIsland struct {
sizeCache protoimpl.SizeCache
unknownFields protoimpl.UnknownFields
- Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id" bson:"_id"`
- Uid string `protobuf:"bytes,2,opt,name=uid,proto3" json:"uid"`
- Islands map[int32]*DBIslandItem `protobuf:"bytes,4,rep,name=islands,proto3" json:"islands" protobuf_key:"varint,1,opt,name=key,proto3" protobuf_val:"bytes,2,opt,name=value,proto3"` //岛屿
+ Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id" bson:"_id"`
+ Uid string `protobuf:"bytes,2,opt,name=uid,proto3" json:"uid"`
+ Islands map[int32]*DBIslandItem `protobuf:"bytes,4,rep,name=islands,proto3" json:"islands" protobuf_key:"varint,1,opt,name=key,proto3" protobuf_val:"bytes,2,opt,name=value,proto3"` //岛屿
+ Nodes map[int32]int32 `protobuf:"bytes,5,rep,name=nodes,proto3" json:"nodes" protobuf_key:"varint,1,opt,name=key,proto3" protobuf_val:"varint,2,opt,name=value,proto3"` //养成节点
+ Freeprogress int32 `protobuf:"varint,6,opt,name=freeprogress,proto3" json:"freeprogress"` //已领取天数
+ Payprogress int32 `protobuf:"varint,7,opt,name=payprogress,proto3" json:"payprogress"`
+ Vip bool `protobuf:"varint,8,opt,name=vip,proto3" json:"vip"`
}
func (x *DBIsland) Reset() {
@@ -83,6 +87,34 @@ func (x *DBIsland) GetIslands() map[int32]*DBIslandItem {
return nil
}
+func (x *DBIsland) GetNodes() map[int32]int32 {
+ if x != nil {
+ return x.Nodes
+ }
+ return nil
+}
+
+func (x *DBIsland) GetFreeprogress() int32 {
+ if x != nil {
+ return x.Freeprogress
+ }
+ return 0
+}
+
+func (x *DBIsland) GetPayprogress() int32 {
+ if x != nil {
+ return x.Payprogress
+ }
+ return 0
+}
+
+func (x *DBIsland) GetVip() bool {
+ if x != nil {
+ return x.Vip
+ }
+ return false
+}
+
//海岛地图
type DBIslandItem struct {
state protoimpl.MessageState
@@ -143,27 +175,39 @@ var File_island_island_db_proto protoreflect.FileDescriptor
var file_island_island_db_proto_rawDesc = []byte{
0x0a, 0x16, 0x69, 0x73, 0x6c, 0x61, 0x6e, 0x64, 0x2f, 0x69, 0x73, 0x6c, 0x61, 0x6e, 0x64, 0x5f,
- 0x64, 0x62, 0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x22, 0xa9, 0x01, 0x0a, 0x08, 0x44, 0x42, 0x49,
+ 0x64, 0x62, 0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x22, 0xe7, 0x02, 0x0a, 0x08, 0x44, 0x42, 0x49,
0x73, 0x6c, 0x61, 0x6e, 0x64, 0x12, 0x0e, 0x0a, 0x02, 0x69, 0x64, 0x18, 0x01, 0x20, 0x01, 0x28,
0x09, 0x52, 0x02, 0x69, 0x64, 0x12, 0x10, 0x0a, 0x03, 0x75, 0x69, 0x64, 0x18, 0x02, 0x20, 0x01,
0x28, 0x09, 0x52, 0x03, 0x75, 0x69, 0x64, 0x12, 0x30, 0x0a, 0x07, 0x69, 0x73, 0x6c, 0x61, 0x6e,
0x64, 0x73, 0x18, 0x04, 0x20, 0x03, 0x28, 0x0b, 0x32, 0x16, 0x2e, 0x44, 0x42, 0x49, 0x73, 0x6c,
0x61, 0x6e, 0x64, 0x2e, 0x49, 0x73, 0x6c, 0x61, 0x6e, 0x64, 0x73, 0x45, 0x6e, 0x74, 0x72, 0x79,
- 0x52, 0x07, 0x69, 0x73, 0x6c, 0x61, 0x6e, 0x64, 0x73, 0x1a, 0x49, 0x0a, 0x0c, 0x49, 0x73, 0x6c,
- 0x61, 0x6e, 0x64, 0x73, 0x45, 0x6e, 0x74, 0x72, 0x79, 0x12, 0x10, 0x0a, 0x03, 0x6b, 0x65, 0x79,
- 0x18, 0x01, 0x20, 0x01, 0x28, 0x05, 0x52, 0x03, 0x6b, 0x65, 0x79, 0x12, 0x23, 0x0a, 0x05, 0x76,
- 0x61, 0x6c, 0x75, 0x65, 0x18, 0x02, 0x20, 0x01, 0x28, 0x0b, 0x32, 0x0d, 0x2e, 0x44, 0x42, 0x49,
- 0x73, 0x6c, 0x61, 0x6e, 0x64, 0x49, 0x74, 0x65, 0x6d, 0x52, 0x05, 0x76, 0x61, 0x6c, 0x75, 0x65,
- 0x3a, 0x02, 0x38, 0x01, 0x22, 0x88, 0x01, 0x0a, 0x0c, 0x44, 0x42, 0x49, 0x73, 0x6c, 0x61, 0x6e,
- 0x64, 0x49, 0x74, 0x65, 0x6d, 0x12, 0x0e, 0x0a, 0x02, 0x69, 0x64, 0x18, 0x01, 0x20, 0x01, 0x28,
- 0x05, 0x52, 0x02, 0x69, 0x64, 0x12, 0x2e, 0x0a, 0x05, 0x6c, 0x65, 0x76, 0x65, 0x6c, 0x18, 0x02,
- 0x20, 0x03, 0x28, 0x0b, 0x32, 0x18, 0x2e, 0x44, 0x42, 0x49, 0x73, 0x6c, 0x61, 0x6e, 0x64, 0x49,
- 0x74, 0x65, 0x6d, 0x2e, 0x4c, 0x65, 0x76, 0x65, 0x6c, 0x45, 0x6e, 0x74, 0x72, 0x79, 0x52, 0x05,
- 0x6c, 0x65, 0x76, 0x65, 0x6c, 0x1a, 0x38, 0x0a, 0x0a, 0x4c, 0x65, 0x76, 0x65, 0x6c, 0x45, 0x6e,
- 0x74, 0x72, 0x79, 0x12, 0x10, 0x0a, 0x03, 0x6b, 0x65, 0x79, 0x18, 0x01, 0x20, 0x01, 0x28, 0x05,
- 0x52, 0x03, 0x6b, 0x65, 0x79, 0x12, 0x14, 0x0a, 0x05, 0x76, 0x61, 0x6c, 0x75, 0x65, 0x18, 0x02,
- 0x20, 0x01, 0x28, 0x05, 0x52, 0x05, 0x76, 0x61, 0x6c, 0x75, 0x65, 0x3a, 0x02, 0x38, 0x01, 0x42,
- 0x06, 0x5a, 0x04, 0x2e, 0x3b, 0x70, 0x62, 0x62, 0x06, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x33,
+ 0x52, 0x07, 0x69, 0x73, 0x6c, 0x61, 0x6e, 0x64, 0x73, 0x12, 0x2a, 0x0a, 0x05, 0x6e, 0x6f, 0x64,
+ 0x65, 0x73, 0x18, 0x05, 0x20, 0x03, 0x28, 0x0b, 0x32, 0x14, 0x2e, 0x44, 0x42, 0x49, 0x73, 0x6c,
+ 0x61, 0x6e, 0x64, 0x2e, 0x4e, 0x6f, 0x64, 0x65, 0x73, 0x45, 0x6e, 0x74, 0x72, 0x79, 0x52, 0x05,
+ 0x6e, 0x6f, 0x64, 0x65, 0x73, 0x12, 0x22, 0x0a, 0x0c, 0x66, 0x72, 0x65, 0x65, 0x70, 0x72, 0x6f,
+ 0x67, 0x72, 0x65, 0x73, 0x73, 0x18, 0x06, 0x20, 0x01, 0x28, 0x05, 0x52, 0x0c, 0x66, 0x72, 0x65,
+ 0x65, 0x70, 0x72, 0x6f, 0x67, 0x72, 0x65, 0x73, 0x73, 0x12, 0x20, 0x0a, 0x0b, 0x70, 0x61, 0x79,
+ 0x70, 0x72, 0x6f, 0x67, 0x72, 0x65, 0x73, 0x73, 0x18, 0x07, 0x20, 0x01, 0x28, 0x05, 0x52, 0x0b,
+ 0x70, 0x61, 0x79, 0x70, 0x72, 0x6f, 0x67, 0x72, 0x65, 0x73, 0x73, 0x12, 0x10, 0x0a, 0x03, 0x76,
+ 0x69, 0x70, 0x18, 0x08, 0x20, 0x01, 0x28, 0x08, 0x52, 0x03, 0x76, 0x69, 0x70, 0x1a, 0x49, 0x0a,
+ 0x0c, 0x49, 0x73, 0x6c, 0x61, 0x6e, 0x64, 0x73, 0x45, 0x6e, 0x74, 0x72, 0x79, 0x12, 0x10, 0x0a,
+ 0x03, 0x6b, 0x65, 0x79, 0x18, 0x01, 0x20, 0x01, 0x28, 0x05, 0x52, 0x03, 0x6b, 0x65, 0x79, 0x12,
+ 0x23, 0x0a, 0x05, 0x76, 0x61, 0x6c, 0x75, 0x65, 0x18, 0x02, 0x20, 0x01, 0x28, 0x0b, 0x32, 0x0d,
+ 0x2e, 0x44, 0x42, 0x49, 0x73, 0x6c, 0x61, 0x6e, 0x64, 0x49, 0x74, 0x65, 0x6d, 0x52, 0x05, 0x76,
+ 0x61, 0x6c, 0x75, 0x65, 0x3a, 0x02, 0x38, 0x01, 0x1a, 0x38, 0x0a, 0x0a, 0x4e, 0x6f, 0x64, 0x65,
+ 0x73, 0x45, 0x6e, 0x74, 0x72, 0x79, 0x12, 0x10, 0x0a, 0x03, 0x6b, 0x65, 0x79, 0x18, 0x01, 0x20,
+ 0x01, 0x28, 0x05, 0x52, 0x03, 0x6b, 0x65, 0x79, 0x12, 0x14, 0x0a, 0x05, 0x76, 0x61, 0x6c, 0x75,
+ 0x65, 0x18, 0x02, 0x20, 0x01, 0x28, 0x05, 0x52, 0x05, 0x76, 0x61, 0x6c, 0x75, 0x65, 0x3a, 0x02,
+ 0x38, 0x01, 0x22, 0x88, 0x01, 0x0a, 0x0c, 0x44, 0x42, 0x49, 0x73, 0x6c, 0x61, 0x6e, 0x64, 0x49,
+ 0x74, 0x65, 0x6d, 0x12, 0x0e, 0x0a, 0x02, 0x69, 0x64, 0x18, 0x01, 0x20, 0x01, 0x28, 0x05, 0x52,
+ 0x02, 0x69, 0x64, 0x12, 0x2e, 0x0a, 0x05, 0x6c, 0x65, 0x76, 0x65, 0x6c, 0x18, 0x02, 0x20, 0x03,
+ 0x28, 0x0b, 0x32, 0x18, 0x2e, 0x44, 0x42, 0x49, 0x73, 0x6c, 0x61, 0x6e, 0x64, 0x49, 0x74, 0x65,
+ 0x6d, 0x2e, 0x4c, 0x65, 0x76, 0x65, 0x6c, 0x45, 0x6e, 0x74, 0x72, 0x79, 0x52, 0x05, 0x6c, 0x65,
+ 0x76, 0x65, 0x6c, 0x1a, 0x38, 0x0a, 0x0a, 0x4c, 0x65, 0x76, 0x65, 0x6c, 0x45, 0x6e, 0x74, 0x72,
+ 0x79, 0x12, 0x10, 0x0a, 0x03, 0x6b, 0x65, 0x79, 0x18, 0x01, 0x20, 0x01, 0x28, 0x05, 0x52, 0x03,
+ 0x6b, 0x65, 0x79, 0x12, 0x14, 0x0a, 0x05, 0x76, 0x61, 0x6c, 0x75, 0x65, 0x18, 0x02, 0x20, 0x01,
+ 0x28, 0x05, 0x52, 0x05, 0x76, 0x61, 0x6c, 0x75, 0x65, 0x3a, 0x02, 0x38, 0x01, 0x42, 0x06, 0x5a,
+ 0x04, 0x2e, 0x3b, 0x70, 0x62, 0x62, 0x06, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x33,
}
var (
@@ -178,22 +222,24 @@ func file_island_island_db_proto_rawDescGZIP() []byte {
return file_island_island_db_proto_rawDescData
}
-var file_island_island_db_proto_msgTypes = make([]protoimpl.MessageInfo, 4)
+var file_island_island_db_proto_msgTypes = make([]protoimpl.MessageInfo, 5)
var file_island_island_db_proto_goTypes = []interface{}{
(*DBIsland)(nil), // 0: DBIsland
(*DBIslandItem)(nil), // 1: DBIslandItem
nil, // 2: DBIsland.IslandsEntry
- nil, // 3: DBIslandItem.LevelEntry
+ nil, // 3: DBIsland.NodesEntry
+ nil, // 4: DBIslandItem.LevelEntry
}
var file_island_island_db_proto_depIdxs = []int32{
2, // 0: DBIsland.islands:type_name -> DBIsland.IslandsEntry
- 3, // 1: DBIslandItem.level:type_name -> DBIslandItem.LevelEntry
- 1, // 2: DBIsland.IslandsEntry.value:type_name -> DBIslandItem
- 3, // [3:3] is the sub-list for method output_type
- 3, // [3:3] is the sub-list for method input_type
- 3, // [3:3] is the sub-list for extension type_name
- 3, // [3:3] is the sub-list for extension extendee
- 0, // [0:3] is the sub-list for field type_name
+ 3, // 1: DBIsland.nodes:type_name -> DBIsland.NodesEntry
+ 4, // 2: DBIslandItem.level:type_name -> DBIslandItem.LevelEntry
+ 1, // 3: DBIsland.IslandsEntry.value:type_name -> DBIslandItem
+ 4, // [4:4] is the sub-list for method output_type
+ 4, // [4:4] is the sub-list for method input_type
+ 4, // [4:4] is the sub-list for extension type_name
+ 4, // [4:4] is the sub-list for extension extendee
+ 0, // [0:4] is the sub-list for field type_name
}
func init() { file_island_island_db_proto_init() }
@@ -233,7 +279,7 @@ func file_island_island_db_proto_init() {
GoPackagePath: reflect.TypeOf(x{}).PkgPath(),
RawDescriptor: file_island_island_db_proto_rawDesc,
NumEnums: 0,
- NumMessages: 4,
+ NumMessages: 5,
NumExtensions: 0,
NumServices: 0,
},